<?php

/* substitute_data_input_field - takes a string and substitutes all data input field contained in it
   @arg $string - the original string that contains the data query variables
   @arg $host_id - (int) the host ID to match
   @arg $local_graph_id - (int) the graph ID to match
   @returns - the original string with all of the variable substitutions made

   for example, when using "Advanced Ping" template, you can modify title in its graph template from
     |host_description| - Advanced Ping
   to like this:
     Advanced Ping - from |host_hostname| to |input_hostname| (attempts=|input_attempts|, protocol=|input_protocol|)
*/

function substitute_data_input_field($string, $host_id, $local_graph_id) {

	/* determine what graph template is used in this graph
	   -- this code is from lib/functions.php: get_graph_title() */
	$graph_template_id = db_fetch_cell("select
		graph_local.graph_template_id
		from (graph_templates_graph,graph_local)
		where graph_templates_graph.local_graph_id=graph_local.id
		and graph_local.id=$local_graph_id");

	// most of the below code is from
	// lib/html_form_template.php: draw_nontemplated_fields_graph_item()

	/* determine what data (output) field is used in this graph template */
	$task_item_list = db_fetch_assoc("select
		id as graph_template_input_id
		from graph_template_input
		where graph_template_id=$graph_template_id
		and column_name='task_item_id'");

	/* if any field from datasource isn't exist (really?),
	   return title with no change */
	if (sizeof($task_item_list) <= 0) {
		return $string;
	}

	foreach ($task_item_list as $item) {
		/* determine what id is assigned for task item in this graph
		   (task item = an item included in corresponding datasource) */
		$task_item_id = db_fetch_cell("select
			graph_templates_item.task_item_id
			from (graph_templates_item,graph_template_input_defs)
			where graph_template_input_defs.graph_template_item_id=graph_templates_item.local_graph_template_item_id
			and graph_template_input_defs.graph_template_input_id=" . $item["graph_template_input_id"] . "
			and graph_templates_item.local_graph_id=$local_graph_id
			limit 0,1");

		/* determine what datasource has this task item
		   = what datasource is used for this graph */
		$ds = db_fetch_row("select
			local_data_id,
			data_template_id
			from data_template_rrd
			where id=" . $task_item_id);

		/* find record which uses this datasource and data template
		   from data_template_data table */
		$dt = db_fetch_row("select
			id as data_template_data_id,
			data_input_id
			from data_template_data
			where data_template_id=" . $ds["data_template_id"] . "
			and local_data_id=" . $ds["local_data_id"]);

		/* store combination of
		   "id of data input method which used in this datasource" and
		   "id of data_template_data record in this datasource" */
		$id_array[$dt["data_input_id"]] = $dt["data_template_data_id"];
	}

	foreach ($id_array as $data_input_id => $data_template_data_id) {
		/* retrieve data input fields of given data input method
		   which used in this datasource */
		$input_fields = db_fetch_assoc("select
			data_input_fields.data_name, data_input_data.value
			from data_input_fields,data_input_data
			where data_input_fields.id=data_input_data.data_input_field_id
			and data_input_fields.data_input_id=" . $data_input_id . "
			and data_input_data.data_template_data_id=" . $data_template_data_id);

		if (sizeof($input_fields) > 0) {
			foreach ($input_fields as $field) {
				/* if "|input_xxxx|" is found in title string,
				   replace it with actual value */
				$string = stri_replace("|input_" . $field["data_name"] . "|", $field["value"], $string);
			}
		}
	}

	return $string;
}

?>
